<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AppendDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="438"/>
        <source>Add files to the current archive</source>
        <translation>Dodaj pliki do bieżącego archiwum</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="443"/>
        <source>Use password</source>
        <translation>Użyj hasła</translation>
    </message>
</context>
<context>
    <name>CalculateSizeThread</name>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="68"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="136"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>Plik oryginalny %1 nie istnieje, sprawdź i spróbuj ponownie</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="70"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="138"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 nie istnieje na dysku, sprawdź i spróbuj ponownie</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="79"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="147"/>
        <source>You do not have permission to compress %1</source>
        <translation>Nie posiadasz uprawnień, aby skompresować %1</translation>
    </message>
</context>
<context>
    <name>CommentProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="234"/>
        <source>Updating the comment...</source>
        <translation>Aktualizowanie komentarza...</translation>
    </message>
</context>
<context>
    <name>CompressPage</name>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="81"/>
        <source>Next</source>
        <translation>Dalej</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="122"/>
        <source>Please add files</source>
        <translation>Dodaj pliki</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="122"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CompressSettingPage</name>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="146"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="229"/>
        <source>New Archive</source>
        <translation>Nowe archiwum</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="207"/>
        <source>Advanced Options</source>
        <translation>Opcje zaawansowane</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="211"/>
        <source>Compression method</source>
        <translation>Metoda kompresji</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="214"/>
        <source>Encrypt the archive</source>
        <translation>Zaszyfruj archiwum</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="216"/>
        <source>CPU threads</source>
        <translation>Rdzeni CPU</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="218"/>
        <source>Encrypt the file list too</source>
        <translation>Zaszyfruj także listę plików</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="220"/>
        <source>Split to volumes</source>
        <translation>Podziel na woluminy</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="222"/>
        <source>Comment</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="224"/>
        <source>Compress</source>
        <comment>button</comment>
        <translation>Skompresuj</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Store</source>
        <translation>Przechowanie</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Fastest</source>
        <translation>Szybsza</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Fast</source>
        <translation>Szybka</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Normal</source>
        <translation>Normalna</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Good</source>
        <translation>Dokładna</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="243"/>
        <source>Best</source>
        <translation>Najdokładniejsza</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="250"/>
        <source>Single thread</source>
        <translation>Pojedynczy rdzeń</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="250"/>
        <source>2 threads</source>
        <translation>2 rdzenie</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="250"/>
        <source>4 threads</source>
        <translation>4 rdzenie</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="250"/>
        <source>8 threads</source>
        <translation>8 rdzeni</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="260"/>
        <source>Support zip, 7z type only</source>
        <translation>Obsługuje tylko zip, 7z</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="263"/>
        <source>Support 7z type only</source>
        <translation>Obsługuje tylko typ 7z</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="275"/>
        <source>Enter up to %1 characters</source>
        <translation>Wprowadź maksymalnie %1 znaków</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="296"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="297"/>
        <source>Save to</source>
        <translation>Zapisz do</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="489"/>
        <source>Invalid file name</source>
        <translation>Nieprawidłowa nazwa pliku</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="495"/>
        <source>Please enter the path</source>
        <translation>Wprowadź ścieżkę</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="500"/>
        <source>The path does not exist, please retry</source>
        <translation>Ścieżka nie istnieje, spróbuj ponownie</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="505"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nie posiadasz uprawnień do zapisywania plików tutaj, zmień ścieżkę i spróbuj ponownie</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="513"/>
        <source>Too many volumes, please change and retry</source>
        <translation>Za dużo woluminów, zmień i spróbuj ponownie</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="522"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="550"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 nie istnieje na dysku, sprawdź i spróbuj ponownie </translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="528"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="557"/>
        <source>You do not have permission to compress %1</source>
        <translation>Nie posiadasz uprawnień do kompresji %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="548"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>Plik oryginalny %1 nie istnieje, sprawdź i spróbuj ponownie</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="583"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="797"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="797"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Zastąp</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="705"/>
        <source>Total size: %1</source>
        <translation>Całkowity rozmiar: %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="725"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>Użyta nazwa jest taka sama jak skompresowanego archiwum, użyj innej</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="733"/>
        <source>The password for ZIP volumes cannot be in Chinese</source>
        <translation>Hasło dla wolumenów ZIP nie może być w języku Chińskim</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="797"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Istnieje już inny plik o tej samej nazwie, czy chcesz go zastąpić?</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="837"/>
        <source>Only Chinese and English characters and some symbols are supported</source>
        <translation>Obsługiwane są tylko znaki chińskie i angielskie oraz niektóre symbole</translation>
    </message>
</context>
<context>
    <name>CompressView</name>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="296"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="309"/>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="314"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="317"/>
        <source>Open with</source>
        <translation>Otwórz za pomocą</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="321"/>
        <location filename="../src/source/tree/compressview.cpp" line="500"/>
        <source>Select default program</source>
        <translation>Wybierz program domyślny</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="364"/>
        <source>It will permanently delete the file(s). Are you sure you want to continue?</source>
        <translation>Spowoduje to permanentne usunięcie plik(ów). Czy na pewno chcesz kontynuować?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="364"/>
        <location filename="../src/source/tree/compressview.cpp" line="474"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="364"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potwierdź</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="475"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="473"/>
        <source>Do you want to add the archive to the list or open it in new window?</source>
        <translation>Czy chcesz dodać archiwum do listy lub otworzyć je w nowym oknie?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="476"/>
        <source>Open in new window</source>
        <translation>Otwórz w nowym oknie</translation>
    </message>
</context>
<context>
    <name>ConvertDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="312"/>
        <source>Changes to archives in this file type are not supported. Please convert the archive format to save the changes.</source>
        <translation>Zmiany w archiwach w tym typie plików nie są obsługiwane. Przekonwertuj format archiwum, aby zapisać zmiany.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="320"/>
        <source>Convert the format to:</source>
        <translation>Konwertuj format na:</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="344"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="345"/>
        <source>Convert</source>
        <comment>button</comment>
        <translation>Konwertuj</translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <location filename="../src/source/tree/datamodel.cpp" line="70"/>
        <source>item(s)</source>
        <translation>przedmiot(ów)</translation>
    </message>
</context>
<context>
    <name>FailurePage</name>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="87"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>Wypakowanie nie powiodło się</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="100"/>
        <source>Damaged file, unable to extract</source>
        <translation>Uszkodzony plik, nie można wypakować</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="105"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>Ponów</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="108"/>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="56"/>
        <source>Drag file or folder here</source>
        <translation>Przeciągnij tutaj plik lub katalog</translation>
    </message>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="58"/>
        <source>Select File</source>
        <translation>Wybierz plik</translation>
    </message>
</context>
<context>
    <name>LoadCorruptQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="525"/>
        <source>The archive is damaged</source>
        <translation>Archiwum jest uszkodzone</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="528"/>
        <source>Open as read-only</source>
        <translation>Otwórz jako tylko-do-odczytu</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="529"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>LoadingPage</name>
    <message>
        <location filename="../src/source/page/loadingpage.cpp" line="65"/>
        <source>Loading, please wait...</source>
        <translation>Ładowanie, proszę czekać...</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="60"/>
        <location filename="../src/main.cpp" line="61"/>
        <source>Archive Manager</source>
        <translation>Zarządzanie archiwami</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Archive Manager is a fast and lightweight application for creating and extracting archives.</source>
        <translation>Zarządzanie archiwami to szybka i lekka aplikacja do tworzenia i wypakowywania archiwów.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="179"/>
        <source>Open file</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="180"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="276"/>
        <location filename="../src/source/mainwindow.cpp" line="286"/>
        <source>Create New Archive</source>
        <translation>Utwórz nowe archiwum</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="334"/>
        <source>Converting</source>
        <translation>Konwertuję</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="341"/>
        <source>Updating comments</source>
        <translation>Aktualizowanie komentarzy</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="503"/>
        <location filename="../src/source/mainwindow.cpp" line="2071"/>
        <location filename="../src/source/mainwindow.cpp" line="2097"/>
        <location filename="../src/source/mainwindow.cpp" line="2122"/>
        <source>Plugin error</source>
        <translation>Błąd wtyczki</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1284"/>
        <source>Adding successful</source>
        <translation>Dodawanie zakończone pomyślnie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1316"/>
        <location filename="../src/source/mainwindow.cpp" line="2146"/>
        <source>No data in it</source>
        <translation>Brak w nim danych</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1521"/>
        <source>Adding canceled</source>
        <translation>Anulowano dodawanie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1623"/>
        <source>Adding failed</source>
        <translation>Nie udało się dodać</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1676"/>
        <source>Extraction failed: the file name is too long</source>
        <translation>Wypakowanie nie powiodło się: nazwa pliku jest za długa</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1703"/>
        <location filename="../src/source/mainwindow.cpp" line="2142"/>
        <source>Failed to create &quot;%1&quot;</source>
        <translation>Nie udało się utworzyć &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1825"/>
        <source>Open failed: the file name is too long</source>
        <translation>Otwieranie nieudane: nazwa pliku jest za długa</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2044"/>
        <source>Compression successful</source>
        <translation>Skompresowano pomyślnie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2050"/>
        <source>The file name is too long, so the first 60 characters have been intercepted as the file name.</source>
        <translation>Nazwa pliku jest za długa, pierwsze 60 znaków zostało wykorzystanych do stworzenia nazwy.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2079"/>
        <location filename="../src/source/mainwindow.cpp" line="2150"/>
        <source>Insufficient disk space</source>
        <translation>Za mało miejsca na dysku</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2109"/>
        <location filename="../src/source/mainwindow.cpp" line="2130"/>
        <source>Some volumes are missing</source>
        <translation>Brakuje niektórych woluminów</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2134"/>
        <source>Wrong password, please retry</source>
        <translation>Błędne hasło, spróbuj ponownie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2138"/>
        <location filename="../src/source/mainwindow.cpp" line="2162"/>
        <source>The file name is too long. Keep the name within 60 characters please.</source>
        <translation>Nazwa pliku jest za długa, prosimy o zmieszczenie się w limicie 60 znaków.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2159"/>
        <source>Conversion failed</source>
        <translation>Konwersja nie powiodła się</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2297"/>
        <source>Select file</source>
        <translation>Wybierz plik</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3167"/>
        <source>Enter up to %1 characters</source>
        <translation>Wprowadź maksymalnie %1 znaków</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3043"/>
        <source>File info</source>
        <translation>Informacje o pliku</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1393"/>
        <source>Do you want to delete the archive?</source>
        <translation>Czy chcesz usunąć to archiwum?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="533"/>
        <source>%1 was changed on the disk, please import it again.</source>
        <translation>%1 został zmieniony na dysku, zaimportuj go ponownie.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="75"/>
        <source>Archive Manager</source>
        <translation>Zarządzanie archiwami</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="136"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nie posiadasz uprawnień do zapisywania plików tutaj, zmień ścieżkę i spróbuj ponownie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="299"/>
        <source>Adding files to %1</source>
        <translation>Dodawanie plików do %1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="306"/>
        <source>Compressing</source>
        <translation>Kompresowanie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="313"/>
        <source>Extracting</source>
        <translation>Wypakowywanie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="320"/>
        <source>Deleting</source>
        <translation>Usuwanie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="493"/>
        <location filename="../src/source/mainwindow.cpp" line="2867"/>
        <source>Loading, please wait...</source>
        <translation>Ładowanie, proszę czekać...</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="569"/>
        <source>Are you sure you want to stop the ongoing task?</source>
        <translation>Czy na pewno chcesz przerwać zadanie w toku?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1290"/>
        <location filename="../src/source/mainwindow.cpp" line="1417"/>
        <location filename="../src/source/mainwindow.cpp" line="1433"/>
        <source>Updating, please wait...</source>
        <translation>Aktualizuję, proszę czekać...</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1698"/>
        <source>File name too long</source>
        <translation>Nazwa pliku jest za długa</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2075"/>
        <source>Failed to create file</source>
        <translation>Nie udało się utworzyć pliku</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2068"/>
        <source>Compression failed</source>
        <translation>Kompresja nie powiodła się</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2407"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Zastąp</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2471"/>
        <source>Find directory</source>
        <translation>Znajdź katalog</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2094"/>
        <source>Open failed</source>
        <translation>Nie udało się otworzyć</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1619"/>
        <location filename="../src/source/mainwindow.cpp" line="1693"/>
        <location filename="../src/source/mainwindow.cpp" line="1768"/>
        <location filename="../src/source/mainwindow.cpp" line="1823"/>
        <location filename="../src/source/mainwindow.cpp" line="2105"/>
        <source>Wrong password</source>
        <translation>Błędne hasło</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="612"/>
        <location filename="../src/source/mainwindow.cpp" line="645"/>
        <source>The file format is not supported by Archive Manager</source>
        <translation>Format pliku nie jest obsługiwany przez Zarządzanie Archiwami</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="136"/>
        <location filename="../src/source/mainwindow.cpp" line="441"/>
        <location filename="../src/source/mainwindow.cpp" line="503"/>
        <location filename="../src/source/mainwindow.cpp" line="536"/>
        <location filename="../src/source/mainwindow.cpp" line="597"/>
        <location filename="../src/source/mainwindow.cpp" line="603"/>
        <location filename="../src/source/mainwindow.cpp" line="612"/>
        <location filename="../src/source/mainwindow.cpp" line="652"/>
        <location filename="../src/source/mainwindow.cpp" line="1316"/>
        <location filename="../src/source/mainwindow.cpp" line="2278"/>
        <location filename="../src/source/mainwindow.cpp" line="2565"/>
        <location filename="../src/source/mainwindow.cpp" line="2729"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="327"/>
        <source>Renaming</source>
        <translation>Zmienianie nazwy</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="441"/>
        <location filename="../src/source/mainwindow.cpp" line="603"/>
        <source>You do not have permission to load %1</source>
        <translation>Nie posiadasz uprawnień do załadowania %1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="569"/>
        <location filename="../src/source/mainwindow.cpp" line="1393"/>
        <location filename="../src/source/mainwindow.cpp" line="2407"/>
        <location filename="../src/source/mainwindow.cpp" line="2889"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="569"/>
        <location filename="../src/source/mainwindow.cpp" line="1393"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potwierdź</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="597"/>
        <source>No such file or directory</source>
        <translation>Nie ma takiego pliku lub katalogu</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1332"/>
        <source>Extraction successful</source>
        <comment>提取成功</comment>
        <translation>Wypakowano pomyślnie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1542"/>
        <source>Extraction canceled</source>
        <comment>取消提取</comment>
        <translation>Wypakowanie anulowane</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1688"/>
        <location filename="../src/source/mainwindow.cpp" line="1763"/>
        <location filename="../src/source/mainwindow.cpp" line="2101"/>
        <location filename="../src/source/mainwindow.cpp" line="2126"/>
        <source>The archive is damaged</source>
        <translation>Archiwum jest uszkodzone</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2048"/>
        <source>Extraction successful</source>
        <comment>解压成功</comment>
        <translation>Wypakowano pomyślnie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2054"/>
        <source>Conversion successful</source>
        <translation>Konwersja zakończona pomyślnie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2083"/>
        <source>The compressed volumes already exist</source>
        <translation>Skompresowane woluminy już istnieją</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2119"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>Wypakowanie nie powiodło się</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2289"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2293"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2301"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2309"/>
        <source>Display shortcuts</source>
        <translation>Wyświetl skróty</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2321"/>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2399"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>Użyta nazwa jest taka sama jak skompresowanego archiwum, użyj innej</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2407"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Istnieje już inny plik o tej samej nazwie, czy chcesz go zastąpić?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2550"/>
        <source>You cannot add the archive to itself</source>
        <translation>Nie możesz dodać archiwum do siebie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2565"/>
        <source>You cannot add files to archives in this file type</source>
        <translation>Nie można dodawać plików do archiwów w tym typie plików</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2889"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Aktualizowanie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3067"/>
        <source>Basic info</source>
        <translation>Informacje podstawowe</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3083"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3084"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3085"/>
        <source>Location</source>
        <translation>Położenie</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3086"/>
        <source>Time created</source>
        <translation>Data utworzenia</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3087"/>
        <source>Time accessed</source>
        <translation>Ostatni dostęp</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3088"/>
        <source>Time modified</source>
        <translation>Data modyfikacji</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3098"/>
        <source>Archive</source>
        <translation>Archiwum</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3129"/>
        <source>Comment</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="642"/>
        <source>Please check the file association type in the settings of Archive Manager</source>
        <translation>Sprawdź typ skojarzenia plików w ustawieniach Zarządzania Archiwami</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2278"/>
        <source>The archive was changed on the disk, please import it again.</source>
        <translation>Archiwum zostało zmienione na dysku, zaimportuj je ponownie.</translation>
    </message>
</context>
<context>
    <name>MimeTypeDisplayManager</name>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="46"/>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="47"/>
        <source>Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="48"/>
        <source>Video</source>
        <translation>Film</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="49"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="50"/>
        <source>Image</source>
        <translation>Obraz</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="51"/>
        <source>Archive</source>
        <translation>Archiwum</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="53"/>
        <source>Executable</source>
        <translation>Plik wykonywalny</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="52"/>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="54"/>
        <source>Backup file</source>
        <translation>Plik kopii zapasowej</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="55"/>
        <source>Unknown</source>
        <translation>Nieznane</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="280"/>
        <source>Open with</source>
        <translation>Otwórz za pomocą</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="300"/>
        <source>Add other programs</source>
        <translation>Dodaj inne programy</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="301"/>
        <source>Set as default</source>
        <translation>Ustaw jako domyślne</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="303"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="304"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potwierdź</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="308"/>
        <source>Recommended Applications</source>
        <translation>Zalecane aplikacje</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="310"/>
        <source>Other Applications</source>
        <translation>Inne aplikacje</translation>
    </message>
</context>
<context>
    <name>PasswordNeededQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="394"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Plik zaszyfrowany, wprowadź hasło</translation>
    </message>
</context>
<context>
    <name>PreviousLabel</name>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="52"/>
        <source>Current path:</source>
        <translation>Obecna ścieżka:</translation>
    </message>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="60"/>
        <source>Back to: %1</source>
        <translation>Wróć do: %1</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="52"/>
        <source>%1 task(s) in progress</source>
        <translation>%1 zadanie(a) w toku</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="59"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="102"/>
        <source>Task</source>
        <translation>Zadanie</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="65"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="113"/>
        <source>Extracting</source>
        <translation>Wypakowywanie</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="192"/>
        <source>Are you sure you want to stop the extraction?</source>
        <translation>Czy na pewno chcesz zatrzymać wypakowywanie?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>ProgressPage</name>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="59"/>
        <location filename="../src/source/page/progresspage.cpp" line="325"/>
        <location filename="../src/source/page/progresspage.cpp" line="328"/>
        <location filename="../src/source/page/progresspage.cpp" line="331"/>
        <source>Speed</source>
        <comment>compress</comment>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="59"/>
        <location filename="../src/source/page/progresspage.cpp" line="61"/>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="65"/>
        <location filename="../src/source/page/progresspage.cpp" line="69"/>
        <location filename="../src/source/page/progresspage.cpp" line="72"/>
        <location filename="../src/source/page/progresspage.cpp" line="160"/>
        <source>Calculating...</source>
        <translation>Obliczenie...</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="61"/>
        <location filename="../src/source/page/progresspage.cpp" line="335"/>
        <location filename="../src/source/page/progresspage.cpp" line="337"/>
        <source>Speed</source>
        <comment>delete</comment>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="341"/>
        <location filename="../src/source/page/progresspage.cpp" line="343"/>
        <source>Speed</source>
        <comment>rename</comment>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="65"/>
        <location filename="../src/source/page/progresspage.cpp" line="355"/>
        <location filename="../src/source/page/progresspage.cpp" line="357"/>
        <location filename="../src/source/page/progresspage.cpp" line="359"/>
        <source>Speed</source>
        <comment>convert</comment>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="69"/>
        <location filename="../src/source/page/progresspage.cpp" line="347"/>
        <location filename="../src/source/page/progresspage.cpp" line="349"/>
        <location filename="../src/source/page/progresspage.cpp" line="351"/>
        <source>Speed</source>
        <comment>uncompress</comment>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="72"/>
        <location filename="../src/source/page/progresspage.cpp" line="321"/>
        <source>Time left</source>
        <translation>Pozostało</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="131"/>
        <source>Compressing</source>
        <translation>Kompresowanie</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="133"/>
        <source>Deleting</source>
        <translation>Usuwanie</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="135"/>
        <source>Renaming</source>
        <translation>Zmienianie nazwy</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="137"/>
        <source>Converting</source>
        <translation>Konwertuję</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="139"/>
        <location filename="../src/source/page/progresspage.cpp" line="158"/>
        <source>Updating the comment...</source>
        <translation>Aktualizuję komentarz...</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="141"/>
        <source>Extracting</source>
        <translation>Wypakowywanie</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="152"/>
        <location filename="../src/source/page/progresspage.cpp" line="189"/>
        <location filename="../src/source/page/progresspage.cpp" line="375"/>
        <source>Pause</source>
        <comment>button</comment>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="188"/>
        <location filename="../src/source/page/progresspage.cpp" line="404"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="371"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Kontynuuj</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="404"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Zatwierdź</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="393"/>
        <source>Are you sure you want to stop the decompression?</source>
        <translation>Czy na pewno chcesz zatrzymać dekompresję?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="395"/>
        <source>Are you sure you want to stop the deletion?</source>
        <translation>Czy na pewno chcesz zatrzymać usuwanie?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="391"/>
        <location filename="../src/source/page/progresspage.cpp" line="397"/>
        <source>Are you sure you want to stop the compression?</source>
        <translation>Czy na pewno chcesz zatrzymać kompresję?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="399"/>
        <source>Are you sure you want to stop the conversion?</source>
        <translation>Czy na pewno chcesz zatrzymać konwersję?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Time modified</source>
        <translation>Data modyfikacji</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2886"/>
        <source>%1 changed. Do you want to save changes to the archive?</source>
        <translation>%1 został zmieniony. Czy chcesz zapisać zmiany w archiwum? </translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="26"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="27"/>
        <source>Extraction</source>
        <translation>Wypakowywanie</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="28"/>
        <source>Auto create a folder for multiple extracted files</source>
        <translation>Automatycznie utwórz katalog dla wielu wyodrębnionych plików</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="29"/>
        <source>Show extracted files when completed</source>
        <translation>Pokaż wypakowane pliki po zakończeniu</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="30"/>
        <source>File Management</source>
        <translation>Zarządzanie plikami</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="31"/>
        <source>Delete files after compression</source>
        <translation>Usuń pliki po kompresji</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="32"/>
        <source>Files Associated</source>
        <translation>Skojarzenia plików</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="33"/>
        <source>File Type</source>
        <translation>Typy plików</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="208"/>
        <location filename="../src/source/dialog/popupdialog.cpp" line="214"/>
        <location filename="../3rdparty/interface/queries.cpp" line="244"/>
        <source>Skip</source>
        <comment>button</comment>
        <translation>Pomiń</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="209"/>
        <source>Merge</source>
        <comment>button</comment>
        <translation>Scal</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="212"/>
        <location filename="../3rdparty/interface/queries.cpp" line="221"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Istnieje już inny plik o tej samej nazwie, czy chcesz go zastąpić?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="215"/>
        <location filename="../3rdparty/interface/queries.cpp" line="245"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Zastąp</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="483"/>
        <location filename="../3rdparty/interface/queries.cpp" line="405"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="484"/>
        <location filename="../3rdparty/interface/queries.cpp" line="406"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="206"/>
        <source>Another folder with the same name already exists, replace it?</source>
        <translation>Istnieje już inny katalog o tej samej nazwie, czy chcesz go zastąpić?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="218"/>
        <location filename="../3rdparty/interface/queries.cpp" line="226"/>
        <source>Apply to all</source>
        <translation>Zastosuj do wszystkich</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="557"/>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="608"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="609"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="619"/>
        <source>The name already exists</source>
        <translation>Taka nazwa już istnieje</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="195"/>
        <source>Current directory</source>
        <translation>Obecny katalog</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="125"/>
        <source>Clear All</source>
        <translation>Wyczyść wszystko</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="124"/>
        <source>Select All</source>
        <comment>button</comment>
        <translation>Zaznacz wszystko</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="126"/>
        <source>Recommended</source>
        <translation>Zalecane</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="160"/>
        <source>Extract archives to</source>
        <translation>Wypakuj archiwa do</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="205"/>
        <source>Other directory</source>
        <translation>Inny katalog</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="200"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="272"/>
        <source>Delete archives after extraction</source>
        <translation>Usuń archiwa po wypakowaniu</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="299"/>
        <source>Never</source>
        <translation>Nigdy</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="302"/>
        <source>Ask for confirmation</source>
        <translation>Poproś o potwierdzenie</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="305"/>
        <source>Always</source>
        <translation>Zawsze</translation>
    </message>
</context>
<context>
    <name>SuccessPage</name>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="79"/>
        <source>Compression successful</source>
        <translation>Skompresowano pomyślnie</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="89"/>
        <source>View</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="92"/>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3324"/>
        <location filename="../src/source/mainwindow.cpp" line="3381"/>
        <source>Open file</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3327"/>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3386"/>
        <source>File info</source>
        <translation>Informacje o pliku</translation>
    </message>
</context>
<context>
    <name>UnCompressPage</name>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="75"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="87"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="116"/>
        <source>Extract to:</source>
        <translation>Wypakuj do:</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="117"/>
        <source>Extract</source>
        <comment>button</comment>
        <translation>Wypakuj</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="193"/>
        <source>The default extraction path does not exist, please retry</source>
        <translation>Domyślna ścieżka wypakowania nie istnieje, spróbuj ponownie</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="195"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nie posiadasz uprawnień do zapisywania plików tutaj, zmień ścieżkę i spróbuj ponownie</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="199"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="213"/>
        <source>Find directory</source>
        <translation>Znajdź katalog</translation>
    </message>
</context>
<context>
    <name>UnCompressView</name>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="401"/>
        <source>You cannot add the archive to itself</source>
        <translation>Nie możesz dodać archiwum do samego siebie</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="401"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="627"/>
        <source>Extract</source>
        <comment>提取</comment>
        <translation>Wypakuj</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="629"/>
        <source>Extract to current directory</source>
        <translation>Wypakuj do bieżącego katalogu</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="631"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="633"/>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="638"/>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="645"/>
        <source>Open with</source>
        <translation>Otwórz za pomocą</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="649"/>
        <location filename="../src/source/tree/uncompressview.cpp" line="790"/>
        <source>Select default program</source>
        <translation>Wybierz program domyślny</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="700"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="700"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Zatwierdź</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="700"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>Czy chcesz usunąć wybrane plik(i)?</translation>
    </message>
</context>
</TS>